# ewoksorange

[![Pipeline](https://github.com/ewoks-kit/ewoksorange/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/ewoks-kit/ewoksorange/actions/workflows/test.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/github/license/ewoks-kit/ewoksorange)](https://github.com/ewoks-kit/ewoksorange/blob/main/LICENSE.md)
[![Coverage](https://codecov.io/gh/ewoks-kit/ewoksorange/branch/main/graph/badge.svg)](https://codecov.io/gh/ewoks-kit/ewoksorange)
[![GitHub Pages](https://img.shields.io/github/deployments/ewoks-kit/ewoksorange/github-pages?label=pages)](https://github.com/ewoks-kit/ewoksorange/deployments/activity_log?environment=github-pages)
[![Docs](https://readthedocs.org/projects/ewoksorange/badge/?version=latest)](https://ewoksorange.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/ewoksorange)](https://pypi.org/project/ewoksorange/)

_ewoksorange_ provides a desktop graphical interface for [ewoks](https://ewoks.readthedocs.io/).

## Getting started

Install the project

```bash
pip install ewoksorange[full]
```

Launch the Orange canvas:

```bash
ewoks-canvas
```

Launch the Orange canvas with the examples add-on

```bash
ewoks-canvas --with-examples
```

Open an existing workflow in the Orange canvas

```bash
ewoks-canvas /path/to/orange_wf.ows
```

For more information, see the [documentation](https://ewoksorange.readthedocs.io/): https://ewoksorange.readthedocs.io/
